@@ -160,7 +160,8 @@ class TellstickLiveClient(object):
             dev = {'id': device.id, 'name': device.name}
             dev['methods'] = device.methods(supported_methods)
             dev['state'] = device.last_sent_command(supported_methods)
-            dev['stateValue'] = str(device.last_sent_value() or '')
+            last_sent = device.last_sent_value()
+            dev['stateValue'] = str('' if last_sent is None else last_sent)
             dev_list.append(dev)
         message = LiveMessage("DevicesReport")
         message.append(dev_list)
